Balanced lto for gcc > 13
This greatly decreases compilation times on multi-core machines. E.g. on my computes profile-build goes from 27.5 to 14.5 seconds. Torom and anematode reported even bigger speedups on discord.
I ran 3 STC tests for this:
no filter: https://tests.stockfishchess.org/tests/view/6aaaa9efdbd128aac8fd5005
only gcc: https://tests.stockfishchess.org/tests/view/6aaac292dbd128aac8fd5029
only gcc >= 14: https://tests.stockfishchess.org/tests/view/6aacc6c6dbd128aac8fd5364 (paused at LLR=1.54)
Combining the data gives `LLR = -2.77` for gcc <= 13 and `LRR = 3.54` for gcc >= 14, which is why this patch is only for gcc version 14 and up.
Local speedtests by me (gcc 16.2.1) and Torom show no slowdown.
closes https://github.com/official-stockfish/Stockfish/pull/7177
No functional change